pub struct ReverseSpan<S>(pub S);Expand description
A splitablespan in reverse. This is useful for making lists in descending order.
Tuple Fields
0: STrait Implementations
Sourceimpl<S: Clone> Clone for ReverseSpan<S>
impl<S: Clone> Clone for ReverseSpan<S>
Sourcefn clone(&self) -> ReverseSpan<S>
fn clone(&self) -> ReverseSpan<S>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<S: Debug> Debug for ReverseSpan<S>
impl<S: Debug> Debug for ReverseSpan<S>
Sourceimpl<S: Default> Default for ReverseSpan<S>
impl<S: Default> Default for ReverseSpan<S>
Sourcefn default() -> ReverseSpan<S>
fn default() -> ReverseSpan<S>
Returns the “default value” for a type. Read more
Sourceimpl<S: HasLength> HasLength for ReverseSpan<S>
impl<S: HasLength> HasLength for ReverseSpan<S>
Sourceimpl<S: Hash> Hash for ReverseSpan<S>
impl<S: Hash> Hash for ReverseSpan<S>
Sourceimpl<S: MergableSpan> MergableSpan for ReverseSpan<S>
impl<S: MergableSpan> MergableSpan for ReverseSpan<S>
Sourceimpl<S: PartialEq> PartialEq for ReverseSpan<S>
impl<S: PartialEq> PartialEq for ReverseSpan<S>
Sourceimpl<S: SplitableSpanCtx<Ctx = ()>> SplitableSpanCtx for ReverseSpan<S>
impl<S: SplitableSpanCtx<Ctx = ()>> SplitableSpanCtx for ReverseSpan<S>
type Ctx = ()
Sourcefn truncate_ctx(&mut self, at: usize, _ctx: &Self::Ctx) -> Self
fn truncate_ctx(&mut self, at: usize, _ctx: &Self::Ctx) -> Self
Split the entry, returning the part of the entry which was jettisoned. After truncating at
pos, self.len() == pos and the returned value contains the rest of the items. Read moreSourcefn truncate_keeping_right_ctx(&mut self, at: usize, _ctx: &Self::Ctx) -> Self
fn truncate_keeping_right_ctx(&mut self, at: usize, _ctx: &Self::Ctx) -> Self
The inverse of truncate. This method mutably truncates an item, keeping all content from
at..item.len() and returning the item range from 0..at.
fn split_ctx(self, at: usize, ctx: &Self::Ctx) -> (Self, Self)
impl<S: Copy> Copy for ReverseSpan<S>
impl<S: Eq> Eq for ReverseSpan<S>
impl<S> StructuralPartialEq for ReverseSpan<S>